# peprock
Foundational Python library

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/peprock)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![uv](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json)](https://github.com/astral-sh/uv)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![codecov](https://codecov.io/gh/Ponte-Energy-Partners/peprock/branch/main/graph/badge.svg?token=LWI96U2WSI)](https://codecov.io/gh/Ponte-Energy-Partners/peprock)
[![test](https://github.com/Ponte-Energy-Partners/peprock/actions/workflows/test.yml/badge.svg)](https://github.com/Ponte-Energy-Partners/peprock/actions/workflows/test.yml)
[![PyPI - Version](https://img.shields.io/pypi/v/peprock)](https://pypi.python.org/pypi/peprock)

**peprock** is a collection of versatile Python libraries, provided as namespace packages:

-   **[peprock.datetime][]**: Date/time and related helpers and constants.
-   **[peprock.models][]**: General purpose model classes.
-   **[peprock.patterns][]**: Reusable software design patterns.
-   **[peprock.subclasses][]**: Class hierarchy helpers.

  [peprock.datetime]: https://api.peprock.ponte.energy/datetime/index.html
  [peprock.models]: https://api.peprock.ponte.energy/models/index.html
  [peprock.patterns]: https://api.peprock.ponte.energy/patterns/index.html
  [peprock.subclasses]: https://api.peprock.ponte.energy/subclasses/index.html

Full API documentation is published to [api.peprock.ponte.energy][].

  [api.peprock.ponte.energy]: https://api.peprock.ponte.energy
